@@ -591,11 +591,14 @@ class WebDriver(object):
         Adds a cookie to your current session.
         
         :Args:
-         - cookie_dict: A dictionary object, with the desired cookie name as the key, and
-            the value being the desired contents.
+         - cookie_dict: A dictionary object, with required keys - "name" and "value";
+            optional keys - "path", "domain", "secure", "expiry"
+
+        Usage: 
+            driver.add_cookie({'name' : 'foo', 'value' : 'bar'})
+            driver.add_cookie({'name' : 'foo', 'value' : 'bar', 'path' : '/'})
+            driver.add_cookie({'name' : 'foo', 'value' : 'bar', 'path' : '/', 'secure':True})
 
-        :Usage:
-            driver.add_cookie({'foo': 'bar',})
         """
         self.execute(Command.ADD_COOKIE, {'cookie': cookie_dict})
 
@@ -624,7 +627,8 @@ class WebDriver(object):
         :Usage:
             driver.set_script_timeout(30)
         """
-        self.execute(Command.SET_SCRIPT_TIMEOUT, {'ms': float(time_to_wait) * 1000})
+        self.execute(Command.SET_SCRIPT_TIMEOUT,
+            {'ms': float(time_to_wait) * 1000})
 
     def find_element(self, by=By.ID, value=None):
         """
@@ -693,7 +697,8 @@ class WebDriver(object):
         :Usage:
             driver.set_window_size(800,600)
         """
-        self.execute(Command.SET_WINDOW_SIZE, {'width':width, 'height':height, 'windowHandle':windowHandle})
+        self.execute(Command.SET_WINDOW_SIZE, {'width': width, 'height': height,
+          'windowHandle': windowHandle})
 
     def get_window_size(self, windowHandle='current'):
         """
@@ -702,7 +707,8 @@ class WebDriver(object):
         :Usage:
             driver.get_window_size()
         """
-        return self.execute(Command.GET_WINDOW_SIZE, {'windowHandle':windowHandle})['value']
+        return self.execute(Command.GET_WINDOW_SIZE,
+            {'windowHandle': windowHandle})['value']
 
     def set_window_position(self, x, y, windowHandle='current'):
         """
@@ -715,7 +721,8 @@ class WebDriver(object):
         :Usage:
             driver.set_window_position(0,0)
         """
-        self.execute(Command.SET_WINDOW_POSITION, {'x':x, 'y':y, 'windowHandle':windowHandle})
+        self.execute(Command.SET_WINDOW_POSITION, {'x': x, 'y': y,
+          'windowHandle': windowHandle})
 
     def get_window_position(self, windowHandle='current'):
         """
@@ -724,4 +731,34 @@ class WebDriver(object):
         :Usage:
             driver.get_window_position()
         """
-        return self.execute(Command.GET_WINDOW_POSITION, {'windowHandle':windowHandle})['value']
+        return self.execute(Command.GET_WINDOW_POSITION,
+            {'windowHandle': windowHandle})['value']
+
+    @property
+    def orientation(self):
+        """
+        Gets the current orientation of the device
+
+        :Usage:
+            orientation = driver.orienation
+        """
+        return self.execute(Command.GET_SCREEN_ORIENTATION)['value']
+
+    @orientation.setter
+    def orientation(self, value):
+        """
+        Sets the current orientation of the device
+
+        :Args:
+         - value: orientation to set it to.
+
+        :Usage:
+            driver.orienation = 'landscape'
+        """
+        allowed_values = ['LANDSCAPE', 'PORTRAIT']
+        if value.upper() in allowed_values:
+            self.execute(Command.SET_SCREEN_ORIENTATION, {'orientation': value})['value']
+        else:
+            raise WebDriverException("You can only set the orienation to 'LANDSCAPE' and 'PORTRAIT'")
+
+
